@@ -153,6 +153,14 @@ require "stringio"
         end
       end
 
+      describe "#tempfile" do
+        it "returns the underlying temporary file" do
+          image = described_class.open(image_path)
+
+          expect(image.tempfile).to be_a(Tempfile)
+        end
+      end
+
       describe "#format" do
         subject { described_class.open(image_path(:jpg)) }
 
@@ -179,10 +187,20 @@ require "stringio"
           }.to change { subject.dimensions }.to [100, 100]
         end
 
-        it "works without an extension" do
-          subject = described_class.open(image_path(:without_extension))
-          expect { subject.format("png") }
-            .to change { File.extname(subject.path) }.from("").to(".png")
+        it "works without an extension with .open" do
+          subject = described_class.open(image_path(:jpg_without_extension))
+          subject.format("png")
+
+          expect(File.extname(subject.path)).to eq ".png"
+          expect(subject.type).to eq "PNG"
+        end
+
+        it "works without an extension with .new" do
+          subject = described_class.new(image_path(:jpg_without_extension))
+          subject.format("png")
+
+          expect(File.extname(subject.path)).to eq ".png"
+          expect(subject.type).to eq "PNG"
         end
 
         it "deletes the previous tempfile" do
@@ -208,6 +226,19 @@ require "stringio"
           expect(subject).to be_valid
         end
 
+        it "reformats a layer" do
+          subject = described_class.open(image_path(:animation))
+          layer = subject.layers.first
+          layer.format('jpg')
+          expect(layer).to be_valid
+          expect(File.exist?(layer.path)).to eq true
+        end
+
+        it "clears the info only at the end" do
+          subject.format('png') { subject.type }
+          expect(subject.type).to eq "PNG"
+        end
+
         it "returns self" do
           expect(subject.format('png')).to eq subject
         end
@@ -297,12 +328,18 @@ require "stringio"
         expect(subject.width).to be_a(Fixnum).and be_nonzero
         expect(subject.height).to be_a(Fixnum).and be_nonzero
         expect(subject.dimensions).to all(be_a(Fixnum))
-        expect(subject.size).to be_a(Fixnum).and be_nonzero
+        expect(subject.size).to be_a(Integer).and be_nonzero
+        expect(subject.human_size).to be_a(String).and be_nonempty
         expect(subject.colorspace).to be_a(String)
         expect(subject.resolution).to all(be_a(Fixnum))
         expect(subject.signature).to match(/[[:alnum:]]{64}/)
       end
 
+      it "generates attributes of layers" do
+        expect(subject.layers[0].type).to match(/^[A-Z]+$/)
+        expect(subject.layers[0].size).to be > 0
+      end
+
       it "changes colorspace when called with an argument" do
         expect_any_instance_of(MiniMagick::Tool::Mogrify).to receive(:call)
         subject.colorspace("Gray")
@@ -343,9 +380,44 @@ require "stringio"
         it "returns a hash of verbose information" do
           expect(subject.details["Format"]).to match /^JPEG/
           if MiniMagick.cli == :imagemagick
-            expect(subject.details["Channel depth"]["red"]).not_to be_empty
+            expect(subject.details["Channel depth"]["red"]).to eq "8-bit"
+            expect(subject.details).to have_key("Background color")
+            expect(subject.details["Properties"]).to have_key("date:create")
           else
-            expect(subject.details["Channel Depths"]["Red"]).not_to be_empty
+            expect(subject.details["Channel Depths"]["Red"]).to eq "8 bits"
+            expect(subject.details).to have_key("Resolution")
+          end
+        end
+
+        context "when verbose information includes an empty line" do
+          subject { described_class.new(image_path(:empty_identify_line)) }
+          it "skips the empty line" do
+            if MiniMagick.cli == :imagemagick
+              expect(subject.details["Properties"]).to have_key("date:create")
+            else
+              expect(subject.details).to have_key("Date:create")
+            end
+          end
+        end
+
+        context "when verbose information includes a badly encoded line do",
+          skip_cli: :graphicsmagick do
+          subject { described_class.new(image_path(:badly_encoded_line)) }
+          it "skips the badly encoded line" do
+            expect(subject.details).not_to have_key("Software")
+          end
+        end
+
+        # GraphicsMagick does not output the clipping path
+        context "when verbose information includes a clipping path",
+          skip_cli: :graphicsmagick do
+          subject { described_class.new(image_path(:clipping_path)) }
+          it "does not hang when parsing verbose data" do
+            # Retrieving .details should happen very quickly but as of v4.3.6
+            # will hang indefinitely without the timeout
+            Timeout::timeout(10) do
+              expect(subject.details['Clipping path'][0..4]).to eq "<?xml"
+            end
           end
         end
       end
@@ -382,19 +454,9 @@ require "stringio"
             expect(subject.resize('20x30!')).to eq subject
           end
 
-          it "can be responed to" do
-            expect(subject.respond_to?(:resize)).to eq true
-          end
-        end
-
-        context "for an unknown method" do
-          it "fails with a NoMethodError" do
-            expect { subject.foo }
-              .to raise_error(NoMethodError, /MiniMagick::Image/)
-          end
-
-          it "cannot be responded to" do
-            expect(subject.respond_to?(:foo)).to eq false
+          it "can be responded to" do
+            expect(subject.respond_to?(:gravity)).to eq true
+            expect(subject.respond_to?(:bla)).to eq false
           end
         end
       end
@@ -411,6 +473,11 @@ require "stringio"
             .to raise_error(NoMethodError)
         end
 
+        it "clears the info only at the end" do
+          subject.combine_options { |c| c.resize('20x30!'); subject.width }
+          expect(subject.dimensions).to eq [20, 30]
+        end
+
         it "returns self" do
           expect(subject.combine_options {}).to eq subject
         end
