@@ -81,31 +81,33 @@ RSpec.describe MiniMagick::Tool do
     end
   end
 
-  ["ImageMagick", "GraphicsMagick"].each do |cli|
-    context "with #{cli}", cli: cli.downcase.to_sym do
-      it "adds dynamically generated operator methods" do
-        subject.help.depth(8)
-        expect(subject.args).to eq %W[-help -depth 8]
-      end
+  describe "#clone" do
+    it "adds an option instead of the default behaviour" do
+      subject.clone
+      expect(subject.args).to eq %W[-clone]
+    end
 
-      it "doesn't just delegate to #method_missing" do
-        expect(subject.class.instance_methods).to include(:help)
-      end
+    it "accepts arguments" do
+      subject.clone(0)
+      expect(subject.args).to eq %W[-clone 0]
+    end
 
-      it "adds dynamically generated creation operator methods" do
-        subject.radial_gradient.canvas "khaki"
-        expect(subject.args).to eq %W[radial-gradient: canvas:khaki]
-      end
+    it "is convertable to plus version" do
+      subject.clone.+
+      expect(subject.args).to eq %W[+clone]
     end
   end
 
-  it "resets the dynamically generated operator methods on CLI change" do
-    MiniMagick.cli = :imagemagick
-    expect(subject).to respond_to(:quiet)
+  describe "#method_missing" do
+    it "adds CLI options" do
+      subject.foo_bar('baz')
+      expect(subject.args).to eq %w[-foo-bar baz]
+    end
+  end
 
-    MiniMagick.cli = :graphicsmagick
-    expect(subject).not_to respond_to(:quiet)
-    expect(subject).to respond_to(:ping)
+  it "defines creation operator methods" do
+    subject.radial_gradient.canvas "khaki"
+    expect(subject.args).to eq %W[radial-gradient: canvas:khaki]
   end
 
   it "doesn't raise errors when false is passed to the constructor" do
